/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.jackrabbit.oak.segment.file;

import java.util.concurrent.TimeUnit;

import org.apache.jackrabbit.guava.common.base.Stopwatch;

/**
 * A stopwatch that is also pretty-printable for usage in log messages.
 */
class PrintableStopwatch {

    /**
     * Create a new {@link PrintableStopwatch} and starts it.
     *
     * @return A new instance of {@link PrintableStopwatch}.
     */
    static PrintableStopwatch createStarted() {
        return new PrintableStopwatch(Stopwatch.createStarted());
    }

    private final Stopwatch stopwatch;

    private PrintableStopwatch(Stopwatch stopwatch) {
        this.stopwatch = stopwatch;
    }

    @Override
    public String toString() {
        return String.format("%s (%d ms)", stopwatch, stopwatch.elapsed(TimeUnit.MILLISECONDS));
    }

}

